@@ -1,3 +1,4 @@
+from Products.Archetypes import Field
 from Products.PlonePAS import utils
 
 from Products.slideshowfolder import browser
@@ -7,7 +8,7 @@ class SlideShowFolderView(browser.SlideShowFolderView):
     def _getImageCaption(self, item):
         caption = super(
             SlideShowFolderView, self)._getImageCaption(item)
-        creator = item.Creator
+        creator = Field.decode(item.Creator, self.context)
         member = self.context.portal_membership.getMemberById(creator)
         if member is not None:
             creator = member.getProperty('fullname').decode(
